OC.L10N.register(
    "notes",
    {
    "Notes" : "الملاحظات",
    "New note" : "ملاحظة جديدة ",
    "_%n word_::_%n words_" : ["كلمة","كلمة","كلمتان","كلمات","كلمات","كلمات"],
    "Delete note" : "حذف الملاحظة ",
    "Favorite" : "المفضلة ",
    "No notes found" : "لم يتم العثور على ملاحظات"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
